"""___anubis - Framework for running bpp qa"""
from . import account_splitter, arg_parser, feature_splitter, parallelizer, results
__version__ = '0.1.0'
__author__ = 'matthew bahloul <matthew.bahloul@blueprintprep.com>'
__all__ = ['account_splitter', 'arg_parser', 'feature_splitter', 'parallelizer', 'results']
